@@ -12,6 +12,12 @@
 #undef MINOR_VERSION
 #undef PATCH_VERSION
 #undef VERSION_STRING
+#undef HAVE_DL_API
+#undef ENABLE_NLS
+#undef HAVE_CATGETS
+#undef HAVE_GETTEXT
+#undef HAVE_LC_MESSAGES
+#undef HAVE_STPCPY
 
 @BOTTOM@
 
